@@ -1,10 +1,14 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe 'haproxy::instance' do
   let(:default_facts) do
     {
       concat_basedir: '/dne',
-      ipaddress: '10.10.10.10',
+      networking: {
+        ip: '10.10.10.10'
+      }
     }
   end
 
@@ -14,21 +18,21 @@ describe 'haproxy::instance' do
 
   # haproxy::instance with service name "haproxy".
 
-  context 'when on supported platforms' do
+  context 'with haproxy::instance with service name "haproxy' do
     let(:title) { 'haproxy' }
 
     describe 'for OS-agnostic configuration' do
-      %w[Debian RedHat Archlinux FreeBSD].each do |osfamily|
-        context "on #{osfamily} family operatingsystems" do
+      ['Debian', 'RedHat', 'Archlinux', 'FreeBSD'].each do |osfamily|
+        context "when on #{osfamily} family operatingsystems" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'service_ensure' => 'running',
               'package_ensure' => 'present',
-              'package_name'   => 'haproxy',
-              'service_manage' => true,
+              'package_name' => 'haproxy',
+              'service_manage' => true
             }
           end
 
@@ -37,6 +41,7 @@ describe 'haproxy::instance' do
               'ensure' => 'present',
             )
           end
+
           it 'installs the haproxy service' do
             subject.should contain_service('haproxy').with(
               'ensure' => 'running', 'enable' => 'true',
@@ -44,16 +49,17 @@ describe 'haproxy::instance' do
             )
           end
         end
-        context "on #{osfamily} family specifying a package version" do
+
+        context "when on #{osfamily} family specifying a package version" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'service_ensure' => 'running',
               'package_ensure' => '1.7.9-1',
-              'package_name'   => 'haproxy',
-              'service_manage' => true,
+              'package_name' => 'haproxy',
+              'service_manage' => true
             }
           end
 
@@ -62,6 +68,7 @@ describe 'haproxy::instance' do
               'ensure' => '1.7.9-1',
             )
           end
+
           it 'installs the haproxy service' do
             subject.should contain_service('haproxy').with(
               'ensure' => 'running', 'enable' => 'true',
@@ -69,10 +76,11 @@ describe 'haproxy::instance' do
             )
           end
         end
+
         # C9938
-        context "on #{osfamily} when specifying custom content" do
+        context "when on #{osfamily} when specifying custom content" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             { 'custom_fragment' => "listen stats :9090\n  mode http\n  stats uri /\n  stats auth puppet:puppet\n" }
@@ -80,7 +88,7 @@ describe 'haproxy::instance' do
 
           it 'sets the haproxy package' do
             subject.should contain_concat__fragment('haproxy-haproxy-base').with_content(
-              %r{listen stats :9090\n  mode http\n  stats uri \/\n  stats auth puppet:puppet\n},
+              %r{listen stats :9090\n  mode http\n  stats uri /\n  stats auth puppet:puppet\n},
             )
           end
         end
@@ -88,39 +96,43 @@ describe 'haproxy::instance' do
     end
 
     describe 'for linux operating systems' do
-      %w[Debian RedHat Archlinux].each do |osfamily|
-        context "on #{osfamily} family operatingsystems" do
+      ['Debian', 'RedHat', 'Archlinux'].each do |osfamily|
+        context "when on #{osfamily} family operatingsystems" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
 
           it 'sets up /etc/haproxy/haproxy.cfg as a concat resource' do
             subject.should contain_concat('/etc/haproxy/haproxy.cfg').with(
               'owner' => '0',
               'group' => '0',
-              'mode'  => '0640',
+              'mode' => '0640',
             )
           end
+
           it 'manages the chroot directory' do
             subject.should contain_file('/var/lib/haproxy').with(
               'ensure' => 'directory',
-              'owner'  => 'haproxy',
-              'group'  => 'haproxy',
+              'owner' => 'haproxy',
+              'group' => 'haproxy',
             )
           end
+
           it 'contains a header concat fragment' do
             subject.should contain_concat__fragment('haproxy-00-header').with(
-              'target'  => '/etc/haproxy/haproxy.cfg',
-              'order'   => '01',
-              'content' => "# This file managed by Puppet\n",
+              'target' => '/etc/haproxy/haproxy.cfg',
+              'order' => '01',
+              'content' => "# This file is managed by Puppet\n",
             )
           end
+
           it 'contains a haproxy-haproxy-base concat fragment' do
             subject.should contain_concat__fragment('haproxy-haproxy-base').with(
-              'target'  => '/etc/haproxy/haproxy.cfg',
-              'order'   => '10',
+              'target' => '/etc/haproxy/haproxy.cfg',
+              'order' => '10',
             )
           end
+
           describe 'Base concat fragment contents' do
             let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-haproxy-base', 'content').split("\n") }
 
@@ -129,35 +141,41 @@ describe 'haproxy::instance' do
               contents.should include('global')
               contents.should include('defaults')
             end
+
             it 'logs to an ip address for local0' do
               contents.should be_any do |match|
                 match =~ %r{  log  \d+(\.\d+){3} local0}
               end
             end
+
             it 'specifies the default chroot' do
               contents.should include('  chroot  /var/lib/haproxy')
             end
+
             it 'specifies the correct user' do
               contents.should include('  user  haproxy')
             end
+
             it 'specifies the correct group' do
               contents.should include('  group  haproxy')
             end
+
             it 'specifies the correct pidfile' do
               contents.should include('  pidfile  /var/run/haproxy.pid')
             end
           end
         end
+
         context "when on #{osfamily} family operatingsystems without managing the service" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'service_ensure' => true,
               'package_ensure' => 'present',
-              'package_name'   => 'haproxy',
-              'service_manage' => false,
+              'package_name' => 'haproxy',
+              'service_manage' => false
             }
           end
 
@@ -166,34 +184,40 @@ describe 'haproxy::instance' do
               'ensure' => 'present',
             )
           end
+
           it 'does not manage the haproxy service' do
             subject.should_not contain_service('haproxy')
           end
+
           it 'sets up /etc/haproxy/haproxy.cfg as a concat resource' do
             subject.should contain_concat('/etc/haproxy/haproxy.cfg').with(
               'owner' => '0',
               'group' => '0',
-              'mode'  => '0640',
+              'mode' => '0640',
             )
           end
+
           it 'manages the chroot directory' do
             subject.should contain_file('/var/lib/haproxy').with(
               'ensure' => 'directory',
             )
           end
+
           it 'contains a header concat fragment' do
             subject.should contain_concat__fragment('haproxy-00-header').with(
-              'target'  => '/etc/haproxy/haproxy.cfg',
-              'order'   => '01',
-              'content' => "# This file managed by Puppet\n",
+              'target' => '/etc/haproxy/haproxy.cfg',
+              'order' => '01',
+              'content' => "# This file is managed by Puppet\n",
             )
           end
+
           it 'contains a haproxy-base concat fragment' do
             subject.should contain_concat__fragment('haproxy-haproxy-base').with(
-              'target'  => '/etc/haproxy/haproxy.cfg',
-              'order'   => '10',
+              'target' => '/etc/haproxy/haproxy.cfg',
+              'order' => '10',
             )
           end
+
           describe 'Base concat fragment contents' do
             let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-haproxy-base', 'content').split("\n") }
 
@@ -201,33 +225,54 @@ describe 'haproxy::instance' do
               contents.should include('global')
               contents.should include('defaults')
             end
+
             it 'logs to an ip address for local0' do
               contents.should be_any do |match|
                 match =~ %r{  log  \d+(\.\d+){3} local0}
               end
             end
+
             it 'specifies the default chroot' do
               contents.should include('  chroot  /var/lib/haproxy')
             end
+
             it 'specifies the correct user' do
               contents.should include('  user  haproxy')
             end
+
             it 'specifies the correct group' do
               contents.should include('  group  haproxy')
             end
+
             it 'specifies the correct pidfile' do
               contents.should include('  pidfile  /var/run/haproxy.pid')
             end
           end
         end
-        context "on #{osfamily} when specifying a restart_command" do
+
+        context "when on #{osfamily} family operatingsystems without managing the chroot directory" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
+          end
+          let(:params) do
+            {
+              'chroot_dir_manage' => false
+            }
+          end
+
+          it 'does not manage the haproxy chroot directory' do
+            subject.should_not contain_file('/var/lib/haproxy')
+          end
+        end
+
+        context "when on #{osfamily} when specifying a restart_command" do
+          let(:facts) do
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'restart_command' => '/etc/init.d/haproxy reload',
-              'service_manage'  => true,
+              'service_manage' => true
             }
           end
 
@@ -243,21 +288,21 @@ describe 'haproxy::instance' do
 
   # haproxy::instance with 2nd instance and with non-standard service name.
 
-  context 'when on supported platforms' do
+  context 'with haproxy::instance with 2nd instance and with non-standard service name' do
     let(:title) { 'group1' }
 
     describe 'for OS-agnostic configuration' do
-      %w[Debian RedHat Archlinux FreeBSD].each do |osfamily|
-        context "on #{osfamily} family operatingsystems" do
+      ['Debian', 'RedHat', 'Archlinux', 'FreeBSD'].each do |osfamily|
+        context "when on #{osfamily} family operatingsystems" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'service_ensure' => 'running',
               'package_ensure' => 'present',
-              'package_name'   => 'customhaproxy',
-              'service_manage' => true,
+              'package_name' => 'customhaproxy',
+              'service_manage' => true
             }
           end
 
@@ -266,25 +311,29 @@ describe 'haproxy::instance' do
               'ensure' => 'present',
             )
           end
+
           it 'installs the customhaproxy service' do
             subject.should contain_service('haproxy-group1').with(
               'ensure' => 'running', 'enable' => 'true',
               'hasrestart' => 'true', 'hasstatus' => 'true'
             )
           end
+
           it 'does not install the haproxy package' do
             subject.should_not contain_package('haproxy').with(
               'title' => 'haproxy',
             )
           end
+
           it 'does not install the haproxy service' do
             subject.should_not contain_service('haproxy')
           end
         end
+
         # C9938
-        context "on #{osfamily} when specifying custom content" do
+        context "when on #{osfamily} when specifying custom content" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             { 'custom_fragment' => "listen stats :9090\n  mode http\n  stats uri /\n  stats auth puppet:puppet\n" }
@@ -292,7 +341,7 @@ describe 'haproxy::instance' do
 
           it 'sets the haproxy-group1 package' do
             subject.should contain_concat__fragment('haproxy-group1-haproxy-base').with_content(
-              %r{listen stats :9090\n  mode http\n  stats uri \/\n  stats auth puppet:puppet\n},
+              %r{listen stats :9090\n  mode http\n  stats uri /\n  stats auth puppet:puppet\n},
             )
           end
         end
@@ -300,39 +349,43 @@ describe 'haproxy::instance' do
     end
 
     describe 'for linux operating systems' do
-      %w[Debian RedHat Archlinux].each do |osfamily|
-        context "on #{osfamily} family operatingsystems" do
+      ['Debian', 'RedHat', 'Archlinux'].each do |osfamily|
+        context "when on #{osfamily} family operatingsystems" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
 
           it 'sets up /etc/haproxy-group1/haproxy-group1.cfg as a concat resource' do
             subject.should contain_concat('/etc/haproxy-group1/haproxy-group1.cfg').with(
               'owner' => '0',
               'group' => '0',
-              'mode'  => '0640',
+              'mode' => '0640',
             )
           end
+
           it 'manages the chroot directory' do
             subject.should contain_file('/var/lib/haproxy').with(
               'ensure' => 'directory',
-              'owner'  => 'haproxy',
-              'group'  => 'haproxy',
+              'owner' => 'haproxy',
+              'group' => 'haproxy',
             )
           end
+
           it 'contains a header concat fragment' do
             subject.should contain_concat__fragment('haproxy-group1-00-header').with(
-              'target'  => '/etc/haproxy-group1/haproxy-group1.cfg',
-              'order'   => '01',
-              'content' => "# This file managed by Puppet\n",
+              'target' => '/etc/haproxy-group1/haproxy-group1.cfg',
+              'order' => '01',
+              'content' => "# This file is managed by Puppet\n",
             )
           end
+
           it 'contains a haproxy-group1-haproxy-base concat fragment' do
             subject.should contain_concat__fragment('haproxy-group1-haproxy-base').with(
-              'target'  => '/etc/haproxy-group1/haproxy-group1.cfg',
-              'order'   => '10',
+              'target' => '/etc/haproxy-group1/haproxy-group1.cfg',
+              'order' => '10',
             )
           end
+
           describe 'Base concat fragment contents' do
             let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-group1-haproxy-base', 'content').split("\n") }
 
@@ -341,35 +394,41 @@ describe 'haproxy::instance' do
               contents.should include('global')
               contents.should include('defaults')
             end
+
             it 'logs to an ip address for local0' do
               contents.should be_any do |match|
                 match =~ %r{  log  \d+(\.\d+){3} local0}
               end
             end
+
             it 'specifies the default chroot' do
               contents.should include('  chroot  /var/lib/haproxy')
             end
+
             it 'specifies the correct user' do
               contents.should include('  user  haproxy')
             end
+
             it 'specifies the correct group' do
               contents.should include('  group  haproxy')
             end
+
             it 'specifies the correct pidfile' do
               contents.should include('  pidfile  /var/run/haproxy.pid')
             end
           end
         end
-        context "on #{osfamily} family operatingsystems without managing the service" do
+
+        context "when on #{osfamily} family operatingsystems without managing the service" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'service_ensure' => true,
               'package_ensure' => 'present',
-              'package_name'   => 'customhaproxy',
-              'service_manage' => false,
+              'package_name' => 'customhaproxy',
+              'service_manage' => false
             }
           end
 
@@ -378,34 +437,40 @@ describe 'haproxy::instance' do
               'ensure' => 'present',
             )
           end
+
           it 'does not manage the customhaproxy service' do
             subject.should_not contain_service('haproxy-group1')
           end
+
           it 'sets up /etc/haproxy-group1/haproxy-group1.cfg as a concat resource' do
             subject.should contain_concat('/etc/haproxy-group1/haproxy-group1.cfg').with(
               'owner' => '0',
               'group' => '0',
-              'mode'  => '0640',
+              'mode' => '0640',
             )
           end
+
           it 'manages the chroot directory' do
             subject.should contain_file('/var/lib/haproxy').with(
               'ensure' => 'directory',
             )
           end
+
           it 'contains a header concat fragment' do
             subject.should contain_concat__fragment('haproxy-group1-00-header').with(
-              'target'  => '/etc/haproxy-group1/haproxy-group1.cfg',
-              'order'   => '01',
-              'content' => "# This file managed by Puppet\n",
+              'target' => '/etc/haproxy-group1/haproxy-group1.cfg',
+              'order' => '01',
+              'content' => "# This file is managed by Puppet\n",
             )
           end
+
           it 'contains a haproxy-group1-haproxy-base concat fragment' do
             subject.should contain_concat__fragment('haproxy-group1-haproxy-base').with(
-              'target'  => '/etc/haproxy-group1/haproxy-group1.cfg',
-              'order'   => '10',
+              'target' => '/etc/haproxy-group1/haproxy-group1.cfg',
+              'order' => '10',
             )
           end
+
           describe 'Base concat fragment contents' do
             let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-group1-haproxy-base', 'content').split("\n") }
 
@@ -413,33 +478,39 @@ describe 'haproxy::instance' do
               contents.should include('global')
               contents.should include('defaults')
             end
+
             it 'logs to an ip address for local0' do
               contents.should be_any do |match|
                 match =~ %r{  log  \d+(\.\d+){3} local0}
               end
             end
+
             it 'specifies the default chroot' do
               contents.should include('  chroot  /var/lib/haproxy')
             end
+
             it 'specifies the correct user' do
               contents.should include('  user  haproxy')
             end
+
             it 'specifies the correct group' do
               contents.should include('  group  haproxy')
             end
+
             it 'specifies the correct pidfile' do
               contents.should include('  pidfile  /var/run/haproxy.pid')
             end
           end
         end
-        context "on #{osfamily} when specifying a restart_command" do
+
+        context "when on #{osfamily} when specifying a restart_command" do
           let(:facts) do
-            { osfamily: osfamily }.merge default_facts
+            { os: { family: osfamily } }.merge default_facts
           end
           let(:params) do
             {
               'restart_command' => '/etc/init.d/haproxy-group1 reload',
-              'service_manage'  => true,
+              'service_manage' => true
             }
           end
 
@@ -459,34 +530,38 @@ describe 'haproxy::instance' do
 
       context 'when on freebsd family operatingsystems' do
         let(:facts) do
-          { osfamily: 'FreeBSD' }.merge default_facts
+          { os: { family: 'FreeBSD' } }.merge default_facts
         end
 
         it 'sets up /usr/local/etc/haproxy.conf as a concat resource' do
           subject.should contain_concat('/usr/local/etc/haproxy.conf').with(
             'owner' => '0',
             'group' => '0',
-            'mode'  => '0640',
+            'mode' => '0640',
           )
         end
+
         it 'manages the chroot directory' do
           subject.should contain_file('/usr/local/haproxy').with(
             'ensure' => 'directory',
           )
         end
+
         it 'contains a header concat fragment' do
           subject.should contain_concat__fragment('haproxy-00-header').with(
-            'target'  => '/usr/local/etc/haproxy.conf',
-            'order'   => '01',
-            'content' => "# This file managed by Puppet\n",
+            'target' => '/usr/local/etc/haproxy.conf',
+            'order' => '01',
+            'content' => "# This file is managed by Puppet\n",
           )
         end
+
         it 'contains a haproxy-base concat fragment' do
           subject.should contain_concat__fragment('haproxy-haproxy-base').with(
-            'target'  => '/usr/local/etc/haproxy.conf',
-            'order'   => '10',
+            'target' => '/usr/local/etc/haproxy.conf',
+            'order' => '10',
           )
         end
+
         describe 'Base concat fragment contents' do
           let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-haproxy-base', 'content').split("\n") }
 
@@ -495,29 +570,33 @@ describe 'haproxy::instance' do
             contents.should include('global')
             contents.should include('defaults')
           end
+
           it 'logs to an ip address for local0' do
             contents.should be_any do |match|
               match =~ %r{  log  \d+(\.\d+){3} local0}
             end
           end
+
           it 'specifies the default chroot' do
             contents.should include('  chroot  /usr/local/haproxy')
           end
+
           it 'specifies the correct pidfile' do
             contents.should include('  pidfile  /var/run/haproxy.pid')
           end
         end
       end
+
       context 'when on freebsd family operatingsystems without managing the service' do
         let(:facts) do
-          { osfamily: 'FreeBSD' }.merge default_facts
+          { os: { family: 'FreeBSD' } }.merge default_facts
         end
         let(:params) do
           {
             'service_ensure' => true,
             'package_ensure' => 'present',
-            'package_name'   => 'haproxy',
-            'service_manage' => false,
+            'package_name' => 'haproxy',
+            'service_manage' => false
           }
         end
 
@@ -526,34 +605,40 @@ describe 'haproxy::instance' do
             'ensure' => 'present',
           )
         end
+
         it 'does not manage the haproxy service' do
           subject.should_not contain_service('haproxy')
         end
+
         it 'sets up /usr/local/etc/haproxy.conf as a concat resource' do
           subject.should contain_concat('/usr/local/etc/haproxy.conf').with(
             'owner' => '0',
             'group' => '0',
-            'mode'  => '0640',
+            'mode' => '0640',
           )
         end
+
         it 'manages the chroot directory' do
           subject.should contain_file('/usr/local/haproxy').with(
             'ensure' => 'directory',
           )
         end
+
         it 'contains a header concat fragment' do
           subject.should contain_concat__fragment('haproxy-00-header').with(
-            'target'  => '/usr/local/etc/haproxy.conf',
-            'order'   => '01',
-            'content' => "# This file managed by Puppet\n",
+            'target' => '/usr/local/etc/haproxy.conf',
+            'order' => '01',
+            'content' => "# This file is managed by Puppet\n",
           )
         end
+
         it 'contains a haproxy-base concat fragment' do
           subject.should contain_concat__fragment('haproxy-haproxy-base').with(
-            'target'  => '/usr/local/etc/haproxy.conf',
-            'order'   => '10',
+            'target' => '/usr/local/etc/haproxy.conf',
+            'order' => '10',
           )
         end
+
         describe 'Base concat fragment contents' do
           let(:contents) { param_value(catalogue, 'concat::fragment', 'haproxy-haproxy-base', 'content').split("\n") }
 
@@ -561,27 +646,31 @@ describe 'haproxy::instance' do
             contents.should include('global')
             contents.should include('defaults')
           end
+
           it 'logs to an ip address for local0' do
             contents.should be_any do |match|
               match =~ %r{  log  \d+(\.\d+){3} local0}
             end
           end
+
           it 'specifies the default chroot' do
             contents.should include('  chroot  /usr/local/haproxy')
           end
+
           it 'specifies the correct pidfile' do
             contents.should include('  pidfile  /var/run/haproxy.pid')
           end
         end
       end
+
       context 'when on freebsd when specifying a restart_command' do
         let(:facts) do
-          { osfamily: 'FreeBSD' }.merge default_facts
+          { os: { family: 'FreeBSD' } }.merge default_facts
         end
         let(:params) do
           {
             'restart_command' => '/usr/local/etc/rc.d/haproxy reload',
-            'service_manage'  => true,
+            'service_manage' => true
           }
         end
 
@@ -598,7 +687,7 @@ describe 'haproxy::instance' do
     describe 'for OS-specific configuration' do
       context 'when only on Debian family operatingsystems' do
         let(:facts) do
-          { osfamily: 'Debian' }.merge default_facts
+          { os: { family: 'Debian' } }.merge default_facts
         end
 
         it 'manages haproxy service defaults' do
@@ -606,13 +695,14 @@ describe 'haproxy::instance' do
           verify_contents(catalogue, '/etc/default/haproxy-group1', ['ENABLED=1'])
         end
       end
+
       context 'when only on Debian family operatingsystems with custom /etc/default' do
         let(:facts) do
-          { osfamily: 'Debian' }.merge default_facts
+          { os: { family: 'Debian' } }.merge default_facts
         end
         let(:params) do
           {
-            'service_options' => 'stuff',
+            'service_options' => 'stuff'
           }
         end
 
@@ -621,9 +711,10 @@ describe 'haproxy::instance' do
           verify_contents(catalogue, '/etc/default/haproxy-group1', ['stuff'])
         end
       end
+
       context 'when only on RedHat family operatingsystems' do
         let(:facts) do
-          { osfamily: 'RedHat' }.merge default_facts
+          { os: { family: 'RedHat' } }.merge default_facts
         end
 
         it 'manages haproxy sysconfig options' do
@@ -639,7 +730,7 @@ describe 'haproxy::instance' do
   context 'when on unsupported operatingsystems' do
     let(:title) { 'haproxy' }
     let(:facts) do
-      { osfamily: 'windows' }.merge default_facts
+      { os: { family: 'windows' } }.merge default_facts
     end
 
     it do
