@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe 'haproxy::peer' do
@@ -10,10 +12,14 @@ describe 'haproxy::peer' do
   let(:title) { 'dero' }
   let(:facts) do
     {
-      ipaddress: '1.1.1.1',
-      hostname: 'dero',
+      networking: {
+        ip: '1.1.1.1',
+        hostname: 'dero'
+      },
       concat_basedir: '/foo',
-      osfamily: 'RedHat',
+      os: {
+        family: 'RedHat'
+      }
     }
   end
 
@@ -21,14 +27,14 @@ describe 'haproxy::peer' do
     let(:params) do
       {
         peers_name: 'tyler',
-        port: 1024,
+        port: 1024
       }
     end
 
     it {
       is_expected.to contain_concat__fragment('haproxy-peers-tyler-dero').with(
-        'order'   => '30-peers-01-tyler-dero',
-        'target'  => '/tmp/haproxy.cfg',
+        'order' => '30-peers-01-tyler-dero',
+        'target' => '/tmp/haproxy.cfg',
         'content' => "  peer dero 1.1.1.1:1024\n",
       )
     }
