@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe 'haproxy::peers' do
@@ -9,9 +11,13 @@ describe 'haproxy::peers' do
   end
   let(:facts) do
     {
-      ipaddress: '1.1.1.1',
+      networking: {
+        ip: '1.1.1.1'
+      },
       concat_basedir: '/foo',
-      osfamily: 'RedHat',
+      os: {
+        family: 'RedHat'
+      }
     }
   end
 
@@ -20,8 +26,8 @@ describe 'haproxy::peers' do
 
     it {
       is_expected.to contain_concat__fragment('haproxy-bar_peers_block').with(
-        'order'   => '30-peers-00-bar',
-        'target'  => '/tmp/haproxy.cfg',
+        'order' => '30-peers-00-bar',
+        'target' => '/tmp/haproxy.cfg',
         'content' => "\npeers bar\n",
       )
     }
